@@ -491,7 +491,8 @@ def reconciled(product):
     # )
 
     # sends the report by email
-    email = CONFIG['ALERT']['to_1']
+    # email = CONFIG['ALERT']['to_1']
+    email = "yona.rasolonjatovo@staff.blueline.mg"
     content = MIMEText(message, 'plain', 'utf-8')
     attachment = MIMEBase('text', 'csv')
     fp = open('/tmp/details_reconciliation.csv', 'rb')
