@@ -201,7 +201,7 @@ def get_history(customer_name, date):
             sql = (
                 "SELECT * FROM fup "
                 "WHERE datetime='{date}'::date "
-                "AND customer='{name}') "
+                "AND customer='{name}' "
             ).format(name=customer_name, date=date)
             rows = db.query(sql)
             fup_history = rows.as_dict()
